from src.matpak.types import mat_t, vec_t

def imp_mat_file(file: str, sep: str = ',') -> mat_t:
    """
    :param file: path to matrix file. each line in file represents a
    :param sep: file's elements separator char; by default, it is comma ','.

    :return: mat_t
    """
    pass


def imp_vec_file(file: str, sep: str = ',') -> vec_t:
    """
    :param file: path to vector file. each element in file represents a vector element.
    :param sep: file's elements separator char; by default, it is comma ','.

    :return: vec_t
    """
    pass



from ctypes import c_uint32
from .types import lst_dec_1d_t


class Vector:
    def __init__(self, rows: c_uint32, init_vec: lst_dec_1d_t | None = None):
        """
        initialize a rows count vector and init_vec list

        :param rows: vector rows count.
        :param init_vec: initial values for vector; or None as default for zero vector.
        """
        pass


from ctypes import c_uint32
from .types import lst_dec_2d_t

class Matrix:
    def __init__(self, rows: c_uint32, cols: c_uint32, init_mat: lst_dec_2d_t | None = None):
        """
        initialize rows*cols matrix with init_mat 2D list elements.

        :param rows: matrix rows count.
        :param cols: matrix cols count.
        :param init_mat: initial rows*cols 2D Decimal values for matrix elements; or None as default for zero matrix.
        """
        pass


from .io import imp_mat_file, imp_vec_file
from .errors import MatrixDimensionsInvalid

from .mat import Matrix
from .vec import Vector

from .types import *

__all__ = ["imp_mat_file", "imp_vec_file", "Matrix", "Vector", "mat_t", "vec_t", "lst_dec_1d_t", "lst_dec_2d_t"]